%global configure_args %{nil}

%bcond_with java

Summary:   Liberty Alliance Single Sign On
Name:      lasso
Version:   2.8.2
Release:   3%{?dist}
License:   GPLv2+
URL:       http://lasso.entrouvert.org/
Source0:   https://dev.entrouvert.org/releases/lasso/lasso-%{version}.tar.gz

Patch3000: fix-removed-xmlsec-deprecations.patch


BuildRequires: autoconf automake check-devel glib2-devel gtk-doc libtool libtool-ltdl-devel
BuildRequires: libxml2-devel openssl-devel swig xmlsec1-devel xmlsec1-openssl-devel zlib-devel
Requires: xmlsec1

%description
Lasso is a library that implements the Liberty Alliance Single Sign On standards, including the SAML
and SAML2 specifications. It allows to handle the whole life-cycle of SAML based Federations, and
provides bindings for multiple languages.

%package devel
Summary: Lasso development headers and documentation
Requires: %{name} = %{version}-%{release}

%description devel
This package contains the header files, static libraries and development documentation for Lasso.

%package -n perl-%{name}
Summary: Liberty Alliance Single Sign On (lasso) Perl bindings
BuildRequires: perl-devel perl-generators perl(Error) perl(warnings) perl(XSLoader)
BuildRequires: perl(ExtUtils::MakeMaker) perl(strict) perl(Test::More)
Requires: perl(:MODULE_COMPAT_%{?perl_version})
Requires: %{name} = %{version}-%{release}

%description -n perl-%{name}
Perl language bindings for the lasso (Liberty Alliance Single Sign On) library.

%if %{with java}
%package -n java-%{name}
Summary: Liberty Alliance Single Sign On (lasso) Java bindings
Buildrequires: java-1.8.0-openjdk-devel jpackage-utils
Requires: java-headless jpackage-utils
Requires: %{name} = %{version}-%{release}

%description -n java-%{name}
Java language bindings for the lasso (Liberty Alliance Single Sign On) library.
%endif

%package -n python3-%{name}
Summary: Liberty Alliance Single Sign On (lasso) Python bindings
BuildRequires: python3 python3-devel python3-lxml python3-six make
Requires: python3 %{name} = %{version}-%{release}

%description -n python3-%{name}
Python language bindings for the lasso (Liberty Alliance Single Sign On)
library.

%prep
%autosetup -n %{name}-%{version} -p1

sed -i -E -e '/^#![[:blank:]]*(\/usr\/bin\/env[[:blank:]]+python[^3]?\>)|(\/usr\/bin\/python[^3]?\>)/d' \
  `grep -r -l -E '^#![[:blank:]]*(/usr/bin/python[^3]?)|(/usr/bin/env[[:blank:]]+python[^3]?)' *`

%build
%if %{with java}
export JAVA_HOME=/usr/lib/jvm/java-1.8.0-openjdk
%endif
./autogen.sh
%configure --with-default-sign-algo=rsa-sha256 --enable-php7=yes --with-php7-config-dir=%{php_inidir} \
    --with-python=%{__python3} \
    --enable-php5=no \
%if %{without java}
    --disable-java \
%endif
    %{nil}
%make_build CFLAGS="%{optflags}"

%check
make check CK_TIMEOUT_MULTIPLIER=10

%install
make install exec_prefix=%{_prefix} DESTDIR=%{buildroot}
find %{buildroot} -type f -name '*.la' -exec rm -f {} \;
find %{buildroot} -type f -name '*.a' -exec rm -f {} \;
find %{buildroot} \( -name perllocal.pod -o -name .packlist \) -exec rm -v {} \;
find %{buildroot}/usr/lib*/perl5 -type f -print |
        sed "s@^%{buildroot}@@g" > %{name}-perl-filelist
if [ "$(cat %{name}-perl-filelist)X" = "X" ] ; then
    echo "ERROR: EMPTY FILE LIST"
    exit -1
fi

rm -fr %{buildroot}%{_defaultdocdir}/%{name}

%files
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/liblasso.so.3*

%files devel
%{_libdir}/liblasso.so
%{_libdir}/pkgconfig/lasso.pc
%{_includedir}/%{name}

%files -n perl-%{name} -f %{name}-perl-filelist

%if %{with java}
%files -n java-%{name}
%{_libdir}/java/libjnilasso.so
%{_javadir}/lasso.jar
%endif

%files -n python3-%{name}
%{python3_sitearch}/lasso.py*
%{python3_sitearch}/_lasso.so
%{python3_sitearch}/__pycache__/*

%changelog
* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.8.2-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.8.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 22 2023 wynnfeng <wynnfeng@tencent.com> - 2.8.2-1
- upgrade to 2.8.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.7.0-4
- Rebuilt for OpenCloudOS Stream 23.05

* Mon Apr 03 2023 rockrezhu <rockerzhu@tencent.com> - 2.7.0-3
- Disable sha1.

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.7.0-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Mar 21 2023 Shuo Wang <abushwang@tencent.com> - 2.7.0-1
- initial build
